@@ -26,9 +26,8 @@ import jp.sourceforge.mergedoc.pleiades.log.Logger;
 public class TranslationTransformer extends AbstractTransformer {
 
 	/** ロガー */
-	@SuppressWarnings("unused")
 	private static final Logger log = Logger.getLogger(TranslationTransformer.class);
-	
+
 	/**
 	 * クラスパス追加対象か判定します。
 	 * <br>
@@ -36,11 +35,13 @@ public class TranslationTransformer extends AbstractTransformer {
 	 * configuration/org.eclipse.osgi/bundles/8/1/.cp/libs/ などに動的配置された場合の対応です。
 	 * <br>
 	 * この処理は Eclipse に依存しているため、
-	 * サブクラス TranslationEclipseTransformer に実装することが望まれます。
+	 * サブクラス TranslationEclipseTransformer を作成し実装することが望まれます。
+	 * @throws IOException 入出力例外が発生した場合
+	 * @throws NotFoundException クラスが見つからない場合
 	 */
 	@Override
-	protected boolean isClassPathTarget(String fullPath, String jarFileName) {
-		
+	protected boolean isClassPathTarget(String fullPath, String jarFileName) throws IOException, NotFoundException {
+
 		if (jarFileName.startsWith("org.eclipse.")) {
 			if (
 				jarFileName.startsWith("org.eclipse.core.resources_") ||
@@ -59,12 +60,14 @@ public class TranslationTransformer extends AbstractTransformer {
 			}
 		} else if (
 				jarFileName.startsWith("mergedoc.jstyle.swt") ||
-				
+
 				// ADT CannotCompileException 回避。多くなれば XML 定義。2013.02.10
+				// lint-api.jar などはロードが遅れるため追加しない (pleiades-config.xml で対応)
 				jarFileName.startsWith("com.android.ide.eclipse.adt_") ||
-				jarFileName.equals("sdklib.jar") ||
-				jarFileName.equals("assetstudio.jar")
+				jarFileName.equals("assetstudio.jar") ||
+				jarFileName.equals("sdklib.jar")
 		) {
+			log.debug("クラスパス追加 %s", fullPath);
 			return true;
 		}
 		return false;
@@ -96,7 +99,7 @@ public class TranslationTransformer extends AbstractTransformer {
 		if (cachedBytecode != null) {
 			return cachedBytecode;
 		}
-		
+
 		// 定義済みの変換除外クラス
 		PleiadesConfig config = PleiadesConfig.getInstance();
 		if (config.isExcludePackage(className)) {
@@ -107,6 +110,11 @@ public class TranslationTransformer extends AbstractTransformer {
 		// バイトコードに翻訳アスペクトを埋め込み
 		CtClass ctClass = createCtClass(bytecode);
 
+		// pleiades-config.xml で使用する descriptor 定義の確認デバッグ
+		//if (className.equals("org.eclipse.core.internal.runtime.ResourceTranslator")) {
+		//	logDescriptor(ctClass);
+		//}
+
 		try {
 			byte[] transformedBytecode = transformClass(ctClass);
 
