@@ -363,5 +363,7 @@ public class TranslationDictionaryTest extends TestCase {
 		assertLookup("Tab ( ≫ )", "タブ ( ≫ )");
 		assertLookup("Carriage Return ( \u00a4 )", "復帰 ( \u00a4 )");
 		assertLookup("Line Feed ( ¶ )", "改行 ( ¶ )");
+		assertLookup("Convert Line Delimiters to Windows (CRLF, \\r\\n, 0D0A, \u00A4¶)",
+			"行区切り文字を Windows に変換 (CRLF, \\r\\n, 0D0A, \u00A4¶)");
 	}
 }
